<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR">
  <context>
    <name>ConfigDialog</name>
    <message>
      <location filename="../config.py" line="86" />
      <source>Using configuration file at:</source>
      <translation>Yapılandırma dosyasını kullanarak:</translation>
    </message>
    <message>
      <location filename="../config.py" line="105" />
      <source>Behavior</source>
      <translation>Davranış</translation>
    </message>
    <message>
      <location filename="../config.py" line="106" />
      <source>Automatically save documents</source>
      <translation>Belgeleri otomatik olarak kaydedin</translation>
    </message>
    <message>
      <location filename="../config.py" line="107" />
      <source>Automatically open last documents on startup</source>
      <translation>Başlangıçta son belgeleri otomatik olarak aç</translation>
    </message>
    <message>
      <location filename="../config.py" line="108" />
      <source>Number of recent documents</source>
      <translation>Son belgelerin sayısı</translation>
    </message>
    <message>
      <location filename="../config.py" line="109" />
      <source>Restore window geometry</source>
      <translation>Pencere boyutlarını sıfırla</translation>
    </message>
    <message>
      <location filename="../config.py" line="110" />
      <source>Default preview state</source>
      <translation>Varsayılan önizleme durumu</translation>
    </message>
    <message>
      <location filename="../config.py" line="111" />
      <source>Open external links in ReText window</source>
      <translation>ReText penceresinde harici bağlantıları aç</translation>
    </message>
    <message>
      <location filename="../config.py" line="112" />
      <source>Markdown syntax extensions (comma-separated)</source>
      <translation>Markdown söz dizimi uzantıları (virgülle ayrılmış)</translation>
    </message>
    <message>
      <location filename="../config.py" line="114" />
      <source>Enable synchronized scrolling for Markdown</source>
      <translation>Markdown için senkronize kaydırmayı etkinleştirin</translation>
    </message>
    <message>
      <location filename="../config.py" line="179" />
      <location filename="../config.py" line="118" />
      <source>Editor</source>
      <translation>Düzenleyici</translation>
    </message>
    <message>
      <location filename="../config.py" line="119" />
      <source>Highlight current line</source>
      <translation>Seçili satırı vurgula</translation>
    </message>
    <message>
      <location filename="../config.py" line="120" />
      <source>Show line numbers</source>
      <translation>Satır numaralarını göster</translation>
    </message>
    <message>
      <location filename="../config.py" line="121" />
      <source>Line numbers are relative to current line</source>
      <translation>Satır numaraları mevcut satıra göredir</translation>
    </message>
    <message>
      <location filename="../config.py" line="122" />
      <source>Tab key inserts spaces</source>
      <translation>Sekme tuşu boşluklar ekler</translation>
    </message>
    <message>
      <location filename="../config.py" line="123" />
      <source>Tabulation width</source>
      <translation>Tablo genişliği</translation>
    </message>
    <message>
      <location filename="../config.py" line="124" />
      <source>Draw vertical line at column</source>
      <translation>Sütuna dikey çizgi çizin</translation>
    </message>
    <message>
      <location filename="../config.py" line="125" />
      <source>Enable soft wrap</source>
      <translation>Yumuşak sarmayı etkinleştir</translation>
    </message>
    <message>
      <location filename="../config.py" line="126" />
      <source>Show document stats</source>
      <translation>Belge istatistiklerini göster</translation>
    </message>
    <message>
      <location filename="../config.py" line="127" />
      <source>Ordered list mode</source>
      <translation>Sıralı liste modu</translation>
    </message>
    <message>
      <location filename="../config.py" line="129" />
      <source>Interface</source>
      <translation>Arayüz</translation>
    </message>
    <message>
      <location filename="../config.py" line="130" />
      <source>Hide toolbar</source>
      <translation>Araç çubuğunu gizle</translation>
    </message>
    <message>
      <location filename="../config.py" line="131" />
      <source>Icon theme name</source>
      <translation>Simge teması adı</translation>
    </message>
    <message>
      <location filename="../config.py" line="132" />
      <source>Stylesheet file</source>
      <translation>Stil sayfası dosyası</translation>
    </message>
    <message>
      <location filename="../config.py" line="133" />
      <source>Hide tabs bar when there is only one tab</source>
      <translation>Yalnızca bir sekme olduğunda sekme çubuğunu gizle</translation>
    </message>
    <message>
      <location filename="../config.py" line="134" />
      <source>Show full path in window title</source>
      <translation>Pencere başlığında tam yolu göster</translation>
    </message>
    <message>
      <location filename="../config.py" line="135" />
      <source>Show directory tree</source>
      <translation>Dizin ağacını göster</translation>
    </message>
    <message>
      <location filename="../config.py" line="136" />
      <source>Working directory</source>
      <translation>Çalışma dizini</translation>
    </message>
    <message>
      <location filename="../config.py" line="161" />
      <source>Help</source>
      <translation>Yardım</translation>
    </message>
    <message>
      <location filename="../config.py" line="180" />
      <source>Live preview</source>
      <translation>Canlı önizleme</translation>
    </message>
    <message>
      <location filename="../config.py" line="181" />
      <source>Normal preview</source>
      <translation>Normal önizleme</translation>
    </message>
    <message>
      <location filename="../config.py" line="186" />
      <source>Disabled</source>
      <translation>Pasif</translation>
    </message>
    <message>
      <location filename="../config.py" line="187" />
      <source>Cursor Line</source>
      <translation>İmleç Çizgisi</translation>
    </message>
    <message>
      <location filename="../config.py" line="188" />
      <source>Wrapped Line</source>
      <translation>Sarılmış Çizgi</translation>
    </message>
    <message>
      <location filename="../config.py" line="193" />
      <source>Increment</source>
      <translation>Artır</translation>
    </message>
    <message>
      <location filename="../config.py" line="194" />
      <source>Repeat</source>
      <translation>Yinele</translation>
    </message>
  </context>
  <context>
    <name>DirectorySelectButton</name>
    <message>
      <location filename="../config.py" line="61" />
      <source>Select directory to open</source>
      <translation>Açılacak dizini seçin</translation>
    </message>
  </context>
  <context>
    <name>EncodingDialog</name>
    <message>
      <location filename="../dialogs.py" line="63" />
      <source>Enter encoding name:</source>
      <translation>Kodlama adını girin:</translation>
    </message>
  </context>
  <context>
    <name>FileDialogButton</name>
    <message>
      <location filename="../config.py" line="35" />
      <source>(none)</source>
      <translation>(yok)</translation>
    </message>
  </context>
  <context>
    <name>FileSelectButton</name>
    <message>
      <location filename="../config.py" line="53" />
      <source>Select file to open</source>
      <translation>Açılacak dosyayı seçin</translation>
    </message>
  </context>
  <context>
    <name>InsertTableDialog</name>
    <message>
      <location filename="../tabledialog.py" line="27" />
      <source>Insert table</source>
      <translation>Tablo ekle</translation>
    </message>
    <message>
      <location filename="../tabledialog.py" line="36" />
      <source>Number of rows</source>
      <translation>Satırların sayısı</translation>
    </message>
    <message>
      <location filename="../tabledialog.py" line="37" />
      <source>Number of columns</source>
      <translation>Sütunların sayısı</translation>
    </message>
  </context>
  <context>
    <name>LocaleDialog</name>
    <message>
      <location filename="../dialogs.py" line="43" />
      <source>Enter locale name (example: en_US)</source>
      <translation>Yerel adı girin (örnek: en_US)</translation>
    </message>
    <message>
      <location filename="../dialogs.py" line="44" />
      <source>It is possible to specify multiple languages, separated by comma.</source>
      <translation>Virgülle ayırarak birden çok dil belirtmek mümkündür.</translation>
    </message>
    <message>
      <location filename="../dialogs.py" line="50" />
      <source>Set as default</source>
      <translation>Öntanımlı olarak ata</translation>
    </message>
  </context>
  <context>
    <name>Proxy</name>
    <message>
      <location filename="../fakevimeditor.py" line="62" />
      <source>No write since last change (add ! to override)</source>
      <translation>Son değişiklikten bu yana yazma yok (geçersiz kılmak için ekleyin !)</translation>
    </message>
    <message>
      <location filename="../fakevimeditor.py" line="118" />
      <source>Information</source>
      <translation>Bilgiler</translation>
    </message>
  </context>
  <context>
    <name>ReTextEdit</name>
    <message>
      <location filename="../editor.py" line="252" />
      <source>Add to dictionary</source>
      <translation>Sözlüğe ekle</translation>
    </message>
    <message>
      <location filename="../editor.py" line="464" />
      <source>Save image</source>
      <translation>Görüntüyü kaydet</translation>
    </message>
    <message>
      <location filename="../editor.py" line="466" />
      <source>Images (*.png *.jpg)</source>
      <translation>Görüntü (*.png *.jpg)</translation>
    </message>
  </context>
  <context>
    <name>ReTextTab</name>
    <message>
      <location filename="../tab.py" line="174" />
      <source>New document</source>
      <translation>Yeni belge</translation>
    </message>
    <message>
      <location filename="../tab.py" line="179" />
      <source>Could not parse file contents, check if you have the &lt;a href="%s"&gt;necessary module&lt;/a&gt; installed!</source>
      <translation>Dosya içeriği ayrıştırılamadı, &lt;a href="%s"&gt;gerekli modülün&lt;/a&gt; kurulu olup olmadığını kontrol edin!</translation>
    </message>
    <message>
      <location filename="../tab.py" line="489" />
      <source>Create missing file?</source>
      <translation>Eksik dosya oluşturulsun mu?</translation>
    </message>
    <message>
      <location filename="../tab.py" line="490" />
      <source>The file '%s' does not exist.

Do you want to create it?</source>
      <translation>'%s' dosyası mevcut değil.

Onu oluşturmak ister misin?</translation>
    </message>
    <message>
      <location filename="../tab.py" line="522" />
      <source>File could not be created</source>
      <translation>Dosya oluşturulamadı</translation>
    </message>
    <message>
      <location filename="../tab.py" line="523" />
      <source>Could not create file '%s': %s</source>
      <translation>'%s' dosyası oluşturulamadı: %s</translation>
    </message>
  </context>
  <context>
    <name>ReTextWindow</name>
    <message>
      <location filename="../window.py" line="91" />
      <source>File toolbar</source>
      <translation>Dosya araç çubuğu</translation>
    </message>
    <message>
      <location filename="../window.py" line="93" />
      <source>Edit toolbar</source>
      <translation>Araç çubuğunu düzenleyin</translation>
    </message>
    <message>
      <location filename="../window.py" line="95" />
      <source>Search toolbar</source>
      <translation>Arama araç çubuğu</translation>
    </message>
    <message>
      <location filename="../window.py" line="99" />
      <source>New</source>
      <translation>Yeni</translation>
    </message>
    <message>
      <location filename="../window.py" line="101" />
      <source>Open</source>
      <translation>Aç</translation>
    </message>
    <message>
      <location filename="../window.py" line="103" />
      <source>Set encoding</source>
      <translation>Kodlamayı ayarlayın</translation>
    </message>
    <message>
      <location filename="../window.py" line="1187" />
      <location filename="../window.py" line="106" />
      <source>Reload</source>
      <translation>Tekrar yükle</translation>
    </message>
    <message>
      <location filename="../window.py" line="109" />
      <source>Save</source>
      <translation>Kaydet</translation>
    </message>
    <message>
      <location filename="../window.py" line="112" />
      <source>Save as</source>
      <translation>Farklı kaydet</translation>
    </message>
    <message>
      <location filename="../window.py" line="114" />
      <source>Next tab</source>
      <translation>Sonraki sekme</translation>
    </message>
    <message>
      <location filename="../window.py" line="116" />
      <source>Previous tab</source>
      <translation>Önceki sekme</translation>
    </message>
    <message>
      <location filename="../window.py" line="118" />
      <source>Close tab</source>
      <translation>Sekmeyi kapat</translation>
    </message>
    <message>
      <location filename="../window.py" line="120" />
      <source>Print</source>
      <translation>Yazdır</translation>
    </message>
    <message>
      <location filename="../window.py" line="122" />
      <source>Print preview</source>
      <translation>Baskı Önizleme</translation>
    </message>
    <message>
      <location filename="../window.py" line="124" />
      <source>View HTML code</source>
      <translation>HTML kodunu göster</translation>
    </message>
    <message>
      <location filename="../window.py" line="125" />
      <source>Change editor font</source>
      <translation>Düzenleyici yazı tipini değiştir</translation>
    </message>
    <message>
      <location filename="../window.py" line="127" />
      <source>Change preview font</source>
      <translation>Önizleme yazı tipini değiştir</translation>
    </message>
    <message>
      <location filename="../window.py" line="129" />
      <source>Find text</source>
      <translation>Metin bul</translation>
    </message>
    <message>
      <location filename="../window.py" line="701" />
      <location filename="../window.py" line="131" />
      <source>Go to line</source>
      <translation>Satıra git</translation>
    </message>
    <message>
      <location filename="../window.py" line="134" />
      <source>Preview</source>
      <translation>Önizle</translation>
    </message>
    <message>
      <location filename="../window.py" line="144" />
      <source>Live preview</source>
      <translation>Canlı önizleme</translation>
    </message>
    <message>
      <location filename="../window.py" line="148" />
      <source>Insert table</source>
      <translation>Tablo ekle</translation>
    </message>
    <message>
      <location filename="../window.py" line="150" />
      <source>Table editing mode</source>
      <translation>Tablo düzenleme modu</translation>
    </message>
    <message>
      <location filename="../window.py" line="153" />
      <source>Insert images by file path</source>
      <translation>Resimleri dosya yoluna göre ekle</translation>
    </message>
    <message>
      <location filename="../window.py" line="156" />
      <source>FakeVim mode</source>
      <translation>FakeVim modu</translation>
    </message>
    <message>
      <location filename="../window.py" line="161" />
      <source>Fullscreen mode</source>
      <translation>Tam ekran modu</translation>
    </message>
    <message>
      <location filename="../window.py" line="649" />
      <location filename="../window.py" line="164" />
      <source>Preferences</source>
      <translation>Tercihler</translation>
    </message>
    <message>
      <location filename="../window.py" line="171" />
      <source>Quit</source>
      <translation>Çıkış</translation>
    </message>
    <message>
      <location filename="../window.py" line="174" />
      <source>Undo</source>
      <translation>Geri al</translation>
    </message>
    <message>
      <location filename="../window.py" line="176" />
      <source>Redo</source>
      <translation>Yinele</translation>
    </message>
    <message>
      <location filename="../window.py" line="178" />
      <source>Copy</source>
      <translation>Kopyala</translation>
    </message>
    <message>
      <location filename="../window.py" line="180" />
      <source>Cut</source>
      <translation>Kes</translation>
    </message>
    <message>
      <location filename="../window.py" line="182" />
      <source>Paste</source>
      <translation>Yapıştır</translation>
    </message>
    <message>
      <location filename="../window.py" line="184" />
      <source>Paste image</source>
      <translation>Resmi yapıştır</translation>
    </message>
    <message>
      <location filename="../window.py" line="186" />
      <source>Move line up</source>
      <translation>Satırı yukarı taşı</translation>
    </message>
    <message>
      <location filename="../window.py" line="188" />
      <source>Move line down</source>
      <translation>Satırı aşağı taşı</translation>
    </message>
    <message>
      <location filename="../window.py" line="196" />
      <source>Enable</source>
      <translation>Etkin</translation>
    </message>
    <message>
      <location filename="../window.py" line="197" />
      <source>Set locale</source>
      <translation>Yerel ayarla</translation>
    </message>
    <message>
      <location filename="../window.py" line="198" />
      <source>Use WebEngine (Chromium) renderer</source>
      <translation>WebEngine (Chromium) oluşturucuyu kullanın</translation>
    </message>
    <message>
      <location filename="../window.py" line="204" />
      <source>Show directory</source>
      <translation>Dizini göster</translation>
    </message>
    <message>
      <location filename="../window.py" line="205" />
      <source>Next</source>
      <translation>Sonraki</translation>
    </message>
    <message>
      <location filename="../window.py" line="207" />
      <source>Previous</source>
      <translation>Önceki</translation>
    </message>
    <message>
      <location filename="../window.py" line="209" />
      <source>Replace</source>
      <translation>Değiştir</translation>
    </message>
    <message>
      <location filename="../window.py" line="211" />
      <source>Replace all</source>
      <translation>Tümünü değiştir</translation>
    </message>
    <message>
      <location filename="../window.py" line="214" />
      <source>Close</source>
      <translation>Kapat</translation>
    </message>
    <message>
      <location filename="../window.py" line="218" />
      <source>Get help online</source>
      <translation>Çevrimiçi yardım alın</translation>
    </message>
    <message>
      <location filename="../window.py" line="219" />
      <source>What's new</source>
      <translation>Neler yeni</translation>
    </message>
    <message>
      <location filename="../window.py" line="220" />
      <source>About ReText</source>
      <translation>ReText hakkında</translation>
    </message>
    <message>
      <location filename="../window.py" line="223" />
      <source>About Qt</source>
      <translation>Qt hakkında</translation>
    </message>
    <message>
      <location filename="../window.py" line="238" />
      <source>Bold</source>
      <translation>Kalın</translation>
    </message>
    <message>
      <location filename="../window.py" line="240" />
      <source>Italic</source>
      <translation>İtalik</translation>
    </message>
    <message>
      <location filename="../window.py" line="242" />
      <source>Underline</source>
      <translation>Altı çizili</translation>
    </message>
    <message>
      <location filename="../window.py" line="315" />
      <location filename="../window.py" line="251" />
      <source>Formatting</source>
      <translation>Biçim</translation>
    </message>
    <message>
      <location filename="../window.py" line="255" />
      <source>Symbols</source>
      <translation>Semboller</translation>
    </message>
    <message>
      <location filename="../window.py" line="260" />
      <source>&amp;File</source>
      <translation>&amp;Dosya</translation>
    </message>
    <message>
      <location filename="../window.py" line="261" />
      <source>&amp;Edit</source>
      <translation>&amp;Düzenle</translation>
    </message>
    <message>
      <location filename="../window.py" line="262" />
      <source>&amp;Help</source>
      <translation>&amp;Yardım</translation>
    </message>
    <message>
      <location filename="../window.py" line="265" />
      <source>Open recent</source>
      <translation>Son açılanlar</translation>
    </message>
    <message>
      <location filename="../window.py" line="278" />
      <source>Export</source>
      <translation>Dışarı Aktar</translation>
    </message>
    <message>
      <location filename="../window.py" line="303" />
      <source>Spell check</source>
      <translation>İmlâ kontrolü</translation>
    </message>
    <message>
      <location filename="../window.py" line="312" />
      <source>Default markup</source>
      <translation>Varsayılan biçimlendirme</translation>
    </message>
    <message>
      <location filename="../window.py" line="360" />
      <source>Search</source>
      <translation>Ara</translation>
    </message>
    <message>
      <location filename="../window.py" line="363" />
      <source>Replace with</source>
      <translation>Şununla değiştir</translation>
    </message>
    <message>
      <location filename="../window.py" line="365" />
      <source>Case sensitively</source>
      <translation>Büyük/küçük harf duyarlı</translation>
    </message>
    <message>
      <location filename="../window.py" line="552" />
      <location filename="../window.py" line="506" />
      <source>New document</source>
      <translation>Yeni belge</translation>
    </message>
    <message>
      <location filename="../window.py" line="701" />
      <source>Type the line number</source>
      <translation>Satır numarasını yazın</translation>
    </message>
    <message>
      <location filename="../window.py" line="737" />
      <source>Please, save the file somewhere.</source>
      <translation>Lütfen dosyayı bir yere kaydedin.</translation>
    </message>
    <message>
      <location filename="../window.py" line="856" />
      <source>Select one or several files to open</source>
      <translation>Açmak için bir veya birkaç dosya seçin</translation>
    </message>
    <message>
      <location filename="../window.py" line="1244" />
      <location filename="../window.py" line="857" />
      <source>Supported files</source>
      <translation>Desteklenen dosyalar</translation>
    </message>
    <message>
      <location filename="../window.py" line="1244" />
      <location filename="../window.py" line="857" />
      <source>All files (*)</source>
      <translation>Tüm dosyalar (*)</translation>
    </message>
    <message>
      <location filename="../window.py" line="912" />
      <source>Plain text (*.txt)</source>
      <translation>Düz metin (*.txt)</translation>
    </message>
    <message>
      <location filename="../window.py" line="915" />
      <source>%s files</source>
      <comment>Example of final string: Markdown files</comment>
      <translation>%s dosyalar</translation>
    </message>
    <message>
      <location filename="../window.py" line="984" />
      <location filename="../window.py" line="928" />
      <source>Save file</source>
      <translation>Dosyayı kaydet</translation>
    </message>
    <message>
      <location filename="../window.py" line="936" />
      <source>Cannot save to file which is open in another tab!</source>
      <translation>Başka bir sekmede açık olan dosyaya kaydedilemez!</translation>
    </message>
    <message>
      <location filename="../window.py" line="974" />
      <source>Export document to ODT</source>
      <translation>Belgeyi ODT'ye aktar</translation>
    </message>
    <message>
      <location filename="../window.py" line="975" />
      <source>OpenDocument text files (*.odt)</source>
      <translation>OpenDocument metin dosyası (*.odt)</translation>
    </message>
    <message>
      <location filename="../window.py" line="985" />
      <source>HTML files (*.html *.htm)</source>
      <translation>Html dosyaları (*.html *.htm)</translation>
    </message>
    <message>
      <location filename="../window.py" line="1005" />
      <source>Unrecognized paperSize setting "%s".</source>
      <translation>Tanınmayan kağıt Boyutu ayarları "%s".</translation>
    </message>
    <message>
      <location filename="../window.py" line="1020" />
      <source>Export document to PDF</source>
      <translation>Belgeyi PDF'ye aktar</translation>
    </message>
    <message>
      <location filename="../window.py" line="1022" />
      <source>PDF files (*.pdf)</source>
      <translation>PDF dosyaları (*.pdf)</translation>
    </message>
    <message>
      <location filename="../window.py" line="1046" />
      <source>Print document</source>
      <translation>Belgeyi yazdır</translation>
    </message>
    <message>
      <location filename="../window.py" line="1070" />
      <source>Export document</source>
      <translation>Belgeyi dışa aktar</translation>
    </message>
    <message>
      <location filename="../window.py" line="1090" />
      <source>Failed to execute the command:</source>
      <translation>Komut yürütülemedi:</translation>
    </message>
    <message>
      <location filename="../window.py" line="1126" />
      <source>Alt text</source>
      <translation>Alternatif metin</translation>
    </message>
    <message>
      <location filename="../window.py" line="1127" />
      <location filename="../window.py" line="1126" />
      <source>URL</source>
      <translation>URL</translation>
    </message>
    <message>
      <location filename="../window.py" line="1127" />
      <source>Link text</source>
      <translation>Bağlantı metni</translation>
    </message>
    <message>
      <location filename="../window.py" line="1168" />
      <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
      <translation>Bu dosya başka bir uygulama tarafından silindi.
Lütfen çıkmadan önce dosyayı kaydettiğinizden emin olun.</translation>
    </message>
    <message>
      <location filename="../window.py" line="1177" />
      <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
      <translation>Bu belge başka bir uygulama tarafından değiştirildi.
Dosyayı yeniden yüklemek istiyor musunuz (bu, tüm değişikliklerinizi atacaktır)?
</translation>
    </message>
    <message>
      <location filename="../window.py" line="1182" />
      <source>Automatic saving has been temporarily disabled for this tab to prevent data loss. It will be re-enabled when you reload the file or save it manually.</source>
      <translation>Veri kaybını önlemek için bu sekme için otomatik kaydetme geçici olarak devre dışı bırakıldı. Dosyayı yeniden yüklediğinizde veya kaydettiğinizde yeniden etkinleştirilecektir.</translation>
    </message>
    <message>
      <location filename="../window.py" line="1205" />
      <source>The document has been modified.
Do you want to save your changes?</source>
      <translation>Belge değiştirildi.
Değişikliklerinizi kaydetmek istiyor musunuz?</translation>
    </message>
    <message>
      <location filename="../window.py" line="1232" />
      <source>HTML code</source>
      <translation>HTML kodu</translation>
    </message>
    <message>
      <location filename="../window.py" line="1243" />
      <source>Select one or several images to open</source>
      <translation>Açmak için bir veya birkaç resim seçin</translation>
    </message>
    <message>
      <location filename="../window.py" line="1264" />
      <source>ReText %s (using PyMarkups %s)</source>
      <translation>ReText %s (kullanılan PyMarkups %s)</translation>
    </message>
    <message>
      <location filename="../window.py" line="1265" />
      <source>Simple but powerful editor for Markdown and reStructuredText</source>
      <translation>Markdown ve Yeniden Yapılandırılmış Metin için basit ama güçlü düzenleyici</translation>
    </message>
    <message>
      <location filename="../window.py" line="1267" />
      <source>Author: Dmitry Shachnev, 2011</source>
      <translation>Yazar: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
      <location filename="../window.py" line="1270" />
      <source>Markdown syntax</source>
      <translation>Markdown sözdizimi</translation>
    </message>
    <message>
      <location filename="../window.py" line="1272" />
      <source>reStructuredText syntax</source>
      <translation>yeniden Yapılandırılmış Metin sözdizimi</translation>
    </message>
  </context>
  <context>
    <name>TextInfoArea</name>
    <message>
      <location filename="../editor.py" line="659" />
      <source>%d w | %d a | %d c</source>
      <comment>count of words, alphanumeric characters, all characters</comment>
      <translation>%d w | %d a | %d c</translation>
    </message>
  </context>
  <context>
    <name>main</name>
    <message>
      <location filename="../__main__.py" line="84" />
      <source>Open the files in preview mode</source>
      <translation>Dosyaları önizleme modunda açın</translation>
    </message>
    <message>
      <location filename="../__main__.py" line="86" />
      <source>Create a new window even if there is an existing one</source>
      <translation>Mevcut bir pencere olsa bile yeni bir pencere oluştur</translation>
    </message>
    <message>
      <location filename="../__main__.py" line="90" />
      <source>List of files to open</source>
      <translation>Açılacak dosyaların listesi</translation>
    </message>
  </context>
</TS>
